/*
 * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
 *
 * See the LICENSE file for terms of use.
 */

#include <WContainerWidget>
#include <WSlider>
#include <WText>

#include "PaintExample.h"
#include "ShapesWidget.h"

using namespace Wt;

PaintExample::PaintExample(const WEnvironment& env)
  : WApplication(env)
{
  useStyleSheet("painting.css");

  new WText("<h2>Paint example</h2>"
	    "<p>A simple example demonstrating cross-browser vector graphics."
	    "</p>"
	    "<p>The emweb logo below is painted using the Wt WPainter API, and "
	    "rendered to the browser using inline SVG, inline VML or the "
	    "HTML 5 &lt;canvas&gt; element."
	    "</p>",
	    root());

  WSlider *scaleSlider = new WSlider(Horizontal, root());
  scaleSlider->setMinimum(0);
  scaleSlider->setMaximum(20);
  scaleSlider->setValue(10);
  scaleSlider->setTickInterval(5);
  scaleSlider->setTickPosition(WSlider::TicksBothSides);
  scaleSlider->resize(300, 50);
  scaleSlider->valueChanged.connect(SLOT(this, PaintExample::scaleShape));
  scaleSlider->setMargin(WLength(), WWidget::Left | WWidget::Right);

  WSlider *rotateSlider = new WSlider(Vertical, root());
  rotateSlider->setMinimum(-30);
  rotateSlider->setMaximum(30);
  rotateSlider->setValue(0);
  rotateSlider->setTickInterval(10);
  rotateSlider->setTickPosition(WSlider::TicksBothSides);
  rotateSlider->resize(50, 400);
  rotateSlider->setFloatSide(WWidget::Left);
  rotateSlider->valueChanged.connect(SLOT(this, PaintExample::rotateShape));

  shapes_ = new ShapesWidget(root());
  shapes_->setAngle(0.0);
  shapes_->setRelativeSize(0.5);
  shapes_->setMargin(WLength(), WWidget::Left | WWidget::Right);
  // Uncomment below to render using SVG instead of Canvas.
  // Make sure that you enable the XHTML1 mime-type in your wt_config.xml
  shapes_->setPreferredMethod(WPaintedWidget::InlineSvgVml);
}

void PaintExample::rotateShape(int v)
{
  shapes_->setAngle(v / 2.0);
  shapes_->setPreferredMethod(v < 0 ? WPaintedWidget::InlineSvgVml
			      : WPaintedWidget::HtmlCanvas);
}

void PaintExample::scaleShape(int v)
{
  shapes_->setRelativeSize(0.1 + 0.9 * (v/20.0));
}

WApplication *createApplication(const WEnvironment& env)
{
  return new PaintExample(env);
}

int main(int argc, char **argv)
{
  return WRun(argc, argv, &createApplication);
}
